pub struct DelayedData<T> {
pub release_at: Instant,
pub item: T,
}Expand description
Data structure holding the data alongside a release timemestamp.
The ordering functionality is defined only over the release timestamp to ensure proper mixing.
Fields
release_at: Instantitem: TTrait Implementations
Sourceimpl<T> From<(Instant, T)> for DelayedData<T>
impl<T> From<(Instant, T)> for DelayedData<T>
Sourceimpl<T> Ord for DelayedData<T>
impl<T> Ord for DelayedData<T>
Sourceimpl<T> PartialEq for DelayedData<T>
impl<T> PartialEq for DelayedData<T>
Sourceimpl<T> PartialOrd for DelayedData<T>
impl<T> PartialOrd for DelayedData<T>
impl<T> Eq for DelayedData<T>